#!/usr/bin/env python
from CeboMsrApiPython import LibraryInterface, DeviceType

# CeboMsr - Python example - Counter.
#
# This example shows how to use a counter. Digital I/O #1 is wired
# to the counter, so every time this I/O is pulsed, the counter will
# react on this event.
#
# Requirements: IO-1 must be connected to CNT (IO-0 on Cebo Stick).
#
# @author Thomas Hoppe

def counterTest(device):
    """
    Configuration and running.
    device: Device to use for test.
    """
    # Create local copies, this shortens the source.
    dp0 = device.getDigitalPorts()[0]
    cnt = device.getCounters()[0]

    # Set IO-1 as output.
    dp0.setOutputEnableMask(0x02)

    # Enable the counter.
    cnt.setEnabled(True)

    # Check the counters current value.
    print("Counter before starting: %d" % cnt.read())

    # Pulse IO-1 3 times.
    for _ in range(3):
        dp0.write(0x02)
        dp0.write(0x00)

    # Check the counters current value.
    print("Counter should be 3: %d" % cnt.read())

    # Reset and ...
    cnt.reset()

    # ... disable the counter.
    cnt.setEnabled(False)

    # Check the counters current value.
    print("Counter should be 0: %d" % cnt.read())

    # Pulse IO-1 3 times, the counter should ignore these pulses.
    for _ in range(3):
        dp0.write(0x02)
        dp0.write(0x00)

    # Check the counters current value.
    print("Counter should still be 0: %d" % cnt.read())

def main():
    """
    The examples main method.
    """
    try:
        # Search for devices ...
        devices = LibraryInterface.enumerate(DeviceType.All)

        # If at least one has been found, use the first one ...
        if (len(devices) > 0):
            device = devices[0]

            # Open device, nothing can be done without doing this.
            device.open()

            # *** DIGITAL PORTS AND ANALOG OUTPUTS ARE MODIFIED DURING THIS ***
            # *** SECTION, SO DO NOT CONNECT ANY PERIPHERALS WITHOUT STUDYING ***
            # *** THE ACTIONS DONE HERE, OTHERWISE YOUR PERIPHERALS MAY BE DAMAGED !!! ***
            counterTest(device)

            # Finalize device usage, this free's up the device, so it can be used
            # again, including other applications.
            device.close()
    except Exception as e:
        print(e)

if (__name__ == "__main__"):
    main()
